@@ -1,5 +1,5 @@
 package AI::Pathfinding::OptimizeMultiple;
-
+$AI::Pathfinding::OptimizeMultiple::VERSION = '0.0.14';
 use strict;
 use warnings;
 
@@ -17,8 +17,6 @@ use MooX qw/late/;
 use PDL;
 use Scalar::Util qw/ blessed /;
 
-our $VERSION = '0.0.13';
-
 has chosen_scans => (isa => 'ArrayRef', is => 'rw');
 has _iter_idx => (isa => 'Int', is => 'rw', default => sub { 0; },);
 has _num_boards => (isa => 'Int', is => 'ro', init_arg => 'num_boards',);
@@ -252,8 +250,8 @@ sub _get_iter_state_params_speed
     return
     {
         quota => $iters_quota,
-        num_solved => $num_solved_in_iter,
-        scan_idx => $selected_scan_idx,
+        num_solved => $num_solved_in_iter->at(0),
+        scan_idx => $selected_scan_idx->at(0),
     };
 }
 
@@ -668,7 +666,7 @@ set of initial conditions (for better average performance).
 
 =head1 VERSION
 
-version 0.0.13
+version 0.0.14
 
 =head1 SYNOPSIS
 
@@ -741,6 +739,10 @@ across a representative number of initial cases, find a scan
 that solves most deals with close-to-optimal performance, by using switch
 tasking.
 
+=head1 VERSION
+
+version 0.0.14
+
 =head1 SUBROUTINES/METHODS
 
 =head2 my $chosen_scans_array_ref = $self->chosen_scans()
@@ -842,8 +844,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=AI-Pathfinding-OptimizeMultiple or
-by email to bug-ai-pathfinding-optimizemultiple@rt.cpan.org.
+https://github.com/shlomif/ai-pathfinding-optimizemultiple/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -960,8 +961,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/fc-solve>
+L<http://github.com/shlomif/fc-solve>
 
-  git clone ssh://git@bitbucket.org/shlomif/fc-solve.git
+  git clone ssh://git@github.com/shlomif/fc-solve.git
 
 =cut
