@@ -1,5 +1,5 @@
 package AI::Pathfinding::OptimizeMultiple::IterState;
-
+$AI::Pathfinding::OptimizeMultiple::IterState::VERSION = '0.0.14';
 use strict;
 use warnings;
 
@@ -9,8 +9,6 @@ use MooX qw/late/;
 
 use PDL ();
 
-our $VERSION = '0.0.13';
-
 use vars (qw(@fields));
 
 has _main => (is => 'rw');
@@ -174,7 +172,11 @@ AI::Pathfinding::OptimizeMultiple::IterState - iteration state object.
 
 =head1 VERSION
 
-version 0.0.13
+version 0.0.14
+
+=head1 VERSION
+
+version 0.0.14
 
 =head1 SUBROUTINES/METHODS
 
@@ -206,31 +208,6 @@ Internal use.
 
 Internal use.
 
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (c) 2010 Shlomi Fish
-
-Permission is hereby granted, free of charge, to any person
-obtaining a copy of this software and associated documentation
-files (the "Software"), to deal in the Software without
-restriction, including without limitation the rights to use,
-copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following
-conditions:
-
-The above copyright notice and this permission notice shall be
-included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-OTHER DEALINGS IN THE SOFTWARE.
-
 =head1 AUTHOR
 
 Shlomi Fish <shlomif@cpan.org>
@@ -246,8 +223,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=AI-Pathfinding-OptimizeMultiple or
-by email to bug-ai-pathfinding-optimizemultiple@rt.cpan.org.
+https://github.com/shlomif/ai-pathfinding-optimizemultiple/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -364,8 +340,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/fc-solve>
+L<http://github.com/shlomif/fc-solve>
 
-  git clone ssh://git@bitbucket.org/shlomif/fc-solve.git
+  git clone ssh://git@github.com/shlomif/fc-solve.git
 
 =cut
