@@ -1,5 +1,5 @@
 package AI::Pathfinding::OptimizeMultiple::ScanRun;
-
+$AI::Pathfinding::OptimizeMultiple::ScanRun::VERSION = '0.0.14';
 use strict;
 use warnings;
 
@@ -7,8 +7,6 @@ use 5.012;
 
 use MooX qw/late/;
 
-our $VERSION = '0.0.13';
-
 has iters => (isa => 'Int', is => 'rw', required => 1);
 has scan_idx => (isa => 'Int', is => 'ro', required => 1);
 
@@ -39,7 +37,7 @@ iterations.
 
 =head1 VERSION
 
-version 0.0.13
+version 0.0.14
 
 =head1 SYNOPSIS
 
@@ -50,6 +48,10 @@ version 0.0.13
 
 A class for scan iterations.
 
+=head1 VERSION
+
+version 0.0.14
+
 =head1 SLOTS
 
 =head2 $scan_run->scan_idx()
@@ -94,8 +96,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=AI-Pathfinding-OptimizeMultiple or
-by email to bug-ai-pathfinding-optimizemultiple@rt.cpan.org.
+https://github.com/shlomif/ai-pathfinding-optimizemultiple/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -212,8 +213,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/fc-solve>
+L<http://github.com/shlomif/fc-solve>
 
-  git clone ssh://git@bitbucket.org/shlomif/fc-solve.git
+  git clone ssh://git@github.com/shlomif/fc-solve.git
 
 =cut
